@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 '''Utilities for spectral processing'''
+import warnings
 
 import numpy as np
 import scipy.fftpack as fft
@@ -10,16 +11,16 @@ import scipy.interpolate
 import six
 
 from . import time_frequency
+from .audio import resample
 from .. import cache
 from .. import util
-from ..util.decorators import moved
-from ..util.deprecation import rename_kw, Deprecated
 from ..util.exceptions import ParameterError
-from ..filters import get_window
+from ..filters import get_window, semitone_filterbank
+from ..filters import window_sumsquare
 
-__all__ = ['stft', 'istft', 'magphase',
+__all__ = ['stft', 'istft', 'magphase', 'iirt',
            'ifgram', 'phase_vocoder',
-           'logamplitude', 'perceptual_weighting',
+           'perceptual_weighting',
            'power_to_db', 'db_to_power',
            'amplitude_to_db', 'db_to_amplitude',
            'fmt']
@@ -154,9 +155,11 @@ def stft(y, n_fft=2048, hop_length=None, win_length=None, window='hann',
     # Reshape so that the window can be broadcast
     fft_window = fft_window.reshape((-1, 1))
 
+    # Check audio is valid
+    util.valid_audio(y)
+
     # Pad the time series so that frames are centered
     if center:
-        util.valid_audio(y)
         y = np.pad(y, int(n_fft // 2), mode=pad_mode)
 
     # Window the time series.
@@ -177,7 +180,7 @@ def stft(y, n_fft=2048, hop_length=None, win_length=None, window='hann',
         # RFFT and Conjugate here to match phase from DPWE code
         stft_matrix[:, bl_s:bl_t] = fft.fft(fft_window *
                                             y_frames[:, bl_s:bl_t],
-                                            axis=0)[:stft_matrix.shape[0]].conj()
+                                            axis=0)[:stft_matrix.shape[0]]
 
     return stft_matrix
 
@@ -286,19 +289,23 @@ def istft(stft_matrix, hop_length=None, win_length=None, window='hann',
     n_frames = stft_matrix.shape[1]
     expected_signal_len = n_fft + hop_length * (n_frames - 1)
     y = np.zeros(expected_signal_len, dtype=dtype)
-    ifft_window_sum = np.zeros(expected_signal_len, dtype=dtype)
-    ifft_window_square = ifft_window * ifft_window
 
     for i in range(n_frames):
         sample = i * hop_length
         spec = stft_matrix[:, i].flatten()
-        spec = np.concatenate((spec.conj(), spec[-2:0:-1]), 0)
+        spec = np.concatenate((spec, spec[-2:0:-1].conj()), 0)
         ytmp = ifft_window * fft.ifft(spec).real
 
         y[sample:(sample + n_fft)] = y[sample:(sample + n_fft)] + ytmp
-        ifft_window_sum[sample:(sample + n_fft)] += ifft_window_square
 
     # Normalize by sum of squared window
+    ifft_window_sum = window_sumsquare(window,
+                                       n_frames,
+                                       win_length=win_length,
+                                       n_fft=n_fft,
+                                       hop_length=hop_length,
+                                       dtype=dtype)
+
     approx_nonzero_indices = ifft_window_sum > util.tiny(ifft_window_sum)
     y[approx_nonzero_indices] /= ifft_window_sum[approx_nonzero_indices]
 
@@ -457,7 +464,7 @@ def ifgram(y, sr=22050, n_fft=2048, hop_length=None, win_length=None,
     # Pylint does not correctly infer the type here, but it's correct.
     # pylint: disable=maybe-no-member
     freq_angular = freq_angular.reshape((-1, 1))
-    bin_offset = (phase * diff_stft).imag / mag
+    bin_offset = (-phase * diff_stft).imag / mag
 
     bin_offset[mag < ref_power**0.5] = 0
 
@@ -474,7 +481,7 @@ def ifgram(y, sr=22050, n_fft=2048, hop_length=None, win_length=None,
     return if_gram, stft_matrix
 
 
-def magphase(D):
+def magphase(D, power=1):
     """Separate a complex-valued spectrogram D into its magnitude (S)
     and phase (P) components, so that `D = S * P`.
 
@@ -483,12 +490,15 @@ def magphase(D):
     ----------
     D       : np.ndarray [shape=(d, t), dtype=complex]
         complex-valued spectrogram
+    power : float > 0
+        Exponent for the magnitude spectrogram,
+        e.g., 1 for energy, 2 for power, etc.
 
 
     Returns
     -------
     D_mag   : np.ndarray [shape=(d, t), dtype=real]
-        magnitude of `D`
+        magnitude of `D`, raised to `power`
     D_phase : np.ndarray [shape=(d, t), dtype=complex]
         `exp(1.j * phi)` where `phi` is the phase of `D`
 
@@ -528,6 +538,7 @@ def magphase(D):
     """
 
     mag = np.abs(D)
+    mag **= power
     phase = np.exp(1.j * np.angle(D))
 
     return mag, phase
@@ -620,8 +631,138 @@ def phase_vocoder(D, rate, hop_length=None):
     return d_stretch
 
 
+@cache(level=20)
+def iirt(y, sr=22050, win_length=2048, hop_length=None, center=True,
+         tuning=0.0, pad_mode='reflect', **kwargs):
+    r'''Time-frequency representation using IIR filters [1]_.
+
+    This function will return a time-frequency representation
+    using a multirate filter bank consisting of IIR filters.
+    First, `y` is resampled as needed according to the provided `sample_rates`.
+    Then, a filterbank with with `n` band-pass filters is designed.
+    The resampled input signals are processed by the filterbank as a whole.
+    (`scipy.signal.filtfilt` is used to make the phase linear.)
+    The output of the filterbank is cut into frames.
+    For each band, the short-time mean-square power (STMSP) is calculated by
+    summing `win_length` subsequent filtered time samples.
+
+    When called with the default set of parameters, it will generate the TF-representation
+    as described in [1]_ (pitch filterbank):
+
+        * 85 filters with MIDI pitches [24, 108] as `center_freqs`.
+        * each filter having a bandwith of one semitone.
+
+    .. [1] Müller, Meinard.
+           "Information Retrieval for Music and Motion."
+           Springer Verlag. 2007.
+
+
+    Parameters
+    ----------
+    y : np.ndarray [shape=(n,)]
+        audio time series
+
+    sr : number > 0 [scalar]
+        sampling rate of `y`
+
+    win_length : int > 0, <= n_fft
+        Window length.
+
+    hop_length : int > 0 [scalar]
+        Hop length, number samples between subsequent frames.
+        If not supplied, defaults to `win_length / 4`.
+
+    center : boolean
+        - If `True`, the signal `y` is padded so that frame
+          `D[:, t]` is centered at `y[t * hop_length]`.
+        - If `False`, then `D[:, t]` begins at `y[t * hop_length]`
+
+    tuning : float in `[-0.5, +0.5)` [scalar]
+        Tuning deviation from A440 in fractions of a bin.
+
+    pad_mode : string
+        If `center=True`, the padding mode to use at the edges of the signal.
+        By default, this function uses reflection padding.
+
+    kwargs : additional keyword arguments
+        Additional arguments for `librosa.filters.semitone_filterbank()`
+        (e.g., could be used to provide another set of `center_freqs` and `sample_rates`).
+
+    Returns
+    -------
+    bands_power : np.ndarray [shape=(n, t), dtype=dtype]
+        Short-time mean-square power for the input signal.
+
+    See Also
+    --------
+    librosa.filters.semitone_filterbank
+    librosa.filters._multirate_fb
+    librosa.filters.mr_frequencies
+    librosa.core.cqt
+    scipy.signal.filtfilt
+
+    Examples
+    --------
+    >>> import matplotlib.pyplot as plt
+    >>> y, sr = librosa.load(librosa.util.example_audio_file())
+    >>> D = librosa.iirt(y)
+    >>> librosa.display.specshow(librosa.amplitude_to_db(D, ref=np.max),
+    ...                          y_axis='cqt_hz', x_axis='time')
+    >>> plt.title('Semitone spectrogram')
+    >>> plt.colorbar(format='%+2.0f dB')
+    >>> plt.tight_layout()
+    '''
+
+    # check audio input
+    util.valid_audio(y)
+
+    # Set the default hop, if it's not already specified
+    if hop_length is None:
+        hop_length = int(win_length // 4)
+
+    # Pad the time series so that frames are centered
+    if center:
+        y = np.pad(y, int(hop_length), mode=pad_mode)
+
+    # get the semitone filterbank
+    filterbank_ct, sample_rates = semitone_filterbank(tuning=tuning, **kwargs)
+
+    # create three downsampled versions of the audio signal
+    y_resampled = []
+
+    y_srs = np.unique(sample_rates)
+
+    for cur_sr in y_srs:
+        y_resampled.append(resample(y, sr, cur_sr))
+
+    # Compute the number of frames that will fit. The end may get truncated.
+    n_frames = 1 + int((len(y) - win_length) / float(hop_length))
+
+    bands_power = []
+
+    for cur_sr, cur_filter in zip(sample_rates, filterbank_ct):
+        factor = float(sr) / float(cur_sr)
+        win_length_STMSP = int(np.round(win_length / factor))
+        hop_length_STMSP = int(np.round(hop_length / factor))
+
+        # filter the signal
+        cur_sr_idx = np.flatnonzero(y_srs == cur_sr)[0]
+
+        cur_filter_output = scipy.signal.filtfilt(cur_filter[0], cur_filter[1],
+                                                  y_resampled[cur_sr_idx])
+
+        # frame the current filter output
+        cur_frames = util.frame(np.ascontiguousarray(cur_filter_output),
+                                frame_length=win_length_STMSP,
+                                hop_length=hop_length_STMSP)
+
+        bands_power.append(factor * np.sum(cur_frames**2, axis=0)[:n_frames])
+
+    return np.asarray(bands_power)
+
+
 @cache(level=30)
-def power_to_db(S, ref=1.0, amin=1e-10, top_db=80.0, ref_power=Deprecated()):
+def power_to_db(S, ref=1.0, amin=1e-10, top_db=80.0):
     """Convert a power spectrogram (amplitude squared) to decibel (dB) units
 
     This computes the scaling ``10 * log10(S / ref)`` in a numerically
@@ -646,11 +787,6 @@ def power_to_db(S, ref=1.0, amin=1e-10, top_db=80.0, ref_power=Deprecated()):
         threshold the output at `top_db` below the peak:
         ``max(10 * log10(S)) - top_db``
 
-    ref_power : scalar or callable
-        .. warning:: This parameter name was deprecated in librosa 0.5.0.
-            Use the `ref` parameter instead.
-            The `ref_power` parameter will be removed in librosa 0.6.0.
-
     Returns
     -------
     S_db   : np.ndarray
@@ -718,14 +854,18 @@ def power_to_db(S, ref=1.0, amin=1e-10, top_db=80.0, ref_power=Deprecated()):
 
     """
 
+    S = np.asarray(S)
+
     if amin <= 0:
         raise ParameterError('amin must be strictly positive')
 
-    magnitude = np.abs(S)
-
-    ref = rename_kw('ref_power', ref_power,
-                    'ref', ref,
-                    '0.5', '0.6')
+    if np.issubdtype(S.dtype, np.complexfloating):
+        warnings.warn('power_to_db was called on complex input so phase '
+                      'information will be discarded. To suppress this warning, '
+                      'call power_to_db(magphase(D, power=2)[0]) instead.')
+        magnitude = np.abs(S)
+    else:
+        magnitude = S
 
     if six.callable(ref):
         # User supplied a function to calculate reference power
@@ -744,9 +884,6 @@ def power_to_db(S, ref=1.0, amin=1e-10, top_db=80.0, ref_power=Deprecated()):
     return log_spec
 
 
-logamplitude = moved('librosa.logamplitude', '0.5', '0.6')(power_to_db)
-
-
 @cache(level=30)
 def db_to_power(S_db, ref=1.0):
     '''Convert a dB-scale spectrogram to a power spectrogram.
@@ -808,12 +945,20 @@ def amplitude_to_db(S, ref=1.0, amin=1e-5, top_db=80.0):
 
     See Also
     --------
-    logamplitude, power_to_db, db_to_amplitude
+    power_to_db, db_to_amplitude
 
     Notes
     -----
     This function caches at level 30.
     '''
+
+    S = np.asarray(S)
+
+    if np.issubdtype(S.dtype, np.complexfloating):
+        warnings.warn('amplitude_to_db was called on complex input so phase '
+                      'information will be discarded. To suppress this warning, '
+                      'call amplitude_to_db(magphase(D)[0]) instead.')
+
     magnitude = np.abs(S)
 
     if six.callable(ref):
@@ -822,8 +967,9 @@ def amplitude_to_db(S, ref=1.0, amin=1e-5, top_db=80.0):
     else:
         ref_value = np.abs(ref)
 
-    magnitude **= 2
-    return power_to_db(magnitude, ref=ref_value**2, amin=amin**2,
+    power = np.square(magnitude, out=magnitude)
+
+    return power_to_db(power, ref=ref_value**2, amin=amin**2,
                        top_db=top_db)
 
 
@@ -870,7 +1016,7 @@ def perceptual_weighting(S, frequencies, **kwargs):
         Center frequency for each row of `S`
 
     kwargs : additional keyword arguments
-        Additional keyword arguments to `logamplitude`.
+        Additional keyword arguments to `power_to_db`.
 
     Returns
     -------
@@ -879,7 +1025,7 @@ def perceptual_weighting(S, frequencies, **kwargs):
 
     See Also
     --------
-    logamplitude
+    power_to_db
 
     Notes
     -----
@@ -924,7 +1070,7 @@ def perceptual_weighting(S, frequencies, **kwargs):
 
     offset = time_frequency.A_weighting(frequencies).reshape((-1, 1))
 
-    return offset + logamplitude(S, **kwargs)
+    return offset + power_to_db(S, **kwargs)
 
 
 @cache(level=30)
