@@ -5,8 +5,8 @@
 import sys
 import importlib
 
-short_version = '0.5'
-version = '0.5.1'
+short_version = '0.6'
+version = '0.6.0'
 
 
 def __get_mod_version(modname):
@@ -31,7 +31,7 @@ def show_versions():
     core_deps = ['audioread',
                  'numpy',
                  'scipy',
-                 'scikit-learn',
+                 'sklearn',
                  'joblib',
                  'decorator',
                  'six',
@@ -40,7 +40,7 @@ def show_versions():
     extra_deps = ['numpydoc',
                   'sphinx',
                   'sphinx_rtd_theme',
-                  'sphinxcontrib-versioning',
+                  'sphinxcontrib.versioning',
                   'matplotlib',
                   'numba']
 
